@@ -207,15 +207,21 @@ class ComparatorV01:
             self.format = None
 
     def process_rego_test_case(self):
+        results = []
         inputjson = {}
         result = False
+        rule_expr = get_field_value(self.testcase, 'eval')
+        if not rule_expr:
+            rule_expr = get_field_value(self.testcase, 'evals')
+            if rule_expr:
+                del self.testcase['evals']
+        if not rule_expr:
+            rule_expr = 'data.rule.rulepass'
         opa_exe = opa_binary()
         if not opa_exe:
             # print('*' * 50)
-            return result
-        rule_expr = get_field_value(self.testcase, 'eval')
-        if not rule_expr:
-            rule_expr = 'data.rule.rulepass'
+            results.append({'eval': 'data.rule.rulepass', 'result': "passed" if result else "failed", 'message': ''})
+            return results
         if len(self.testcase['snapshotId'])==1:
             sid = self.testcase['snapshotId'][0]
             inputjson = self.get_snaphotid_doc(sid)
@@ -223,20 +229,17 @@ class ComparatorV01:
             ms_id = dict(zip(self.testcase['snapshotId'], self.testcase['masterSnapshotId']))
             for sid in self.testcase['snapshotId']:
                 inputjson.update({ms_id[sid]: self.get_snaphotid_doc(sid)})
+        results = []
         if inputjson:
             save_json_to_file(inputjson, '/tmp/input.json')
             rego_rule = self.rule
             rego_match=re.match(r'^file\((.*)\)$', rego_rule, re.I)
             if rego_match:
-                # rego_file = get_rego_rule_filename(rego_match.groups()[0], self.container)
                 rego_file = self.rego_rule_filename(rego_match.groups()[0], self.container)
                 if rego_file:
                     pass
                 else:
                     rego_file = None
-                # rego_file1 = self.rego_rule_filename(rego_match.groups()[0], "google_crawler_container")
-                # rego_file1 = self.rego_rule_filename('google_crawler.rego', "google_crawler_container")
-                # print(rego_file1)
             else:
                 rego_txt = [
                     "package rule",
@@ -248,15 +251,41 @@ class ComparatorV01:
                 rego_file = '/tmp/input.rego'
                 open(rego_file, 'w').write('\n'.join(rego_txt))
             if rego_file:
-                os.system('%s eval -i /tmp/input.json -d %s "%s" > /tmp/a.json' % (opa_exe, rego_file, rule_expr))
+                if isinstance(rule_expr, list):
+                    os.system('%s eval -i /tmp/input.json -d %s "data.rule" > /tmp/a.json' % (opa_exe, rego_file))
+                else:
+                    os.system('%s eval -i /tmp/input.json -d %s "%s" > /tmp/a.json' % (opa_exe, rego_file, rule_expr))
                 resultval = json_from_file('/tmp/a.json')
-                if resultval:
-                    resultbool = resultval['result'][0]['expressions'][0]['value'] # [get_field_value(resultval, 'result[0].expressions[0].value')
-                    if resultbool:
+                if resultval and "errors" in resultval and resultval["errors"]:
+                    logger.error(str(resultval["errors"]))
+                    results.append({'eval': rule_expr, 'result': "passed" if result else "failed", 'message': ''})
+                elif resultval:
+                    if isinstance(rule_expr, list):
+                        resultdict = resultval['result'][0]['expressions'][0]['value']
+                        for val in rule_expr:
+                            if 'eval' in val: 
+                                evalfield = val['eval'].rsplit('.', 1)[-1]
+                                evalmessage = val['message'].rsplit('.', 1)[-1] if "message" in val else ""
+                                if evalfield in resultdict:
+                                    if isinstance(resultdict[evalfield], bool):
+                                        result = parsebool(resultdict[evalfield])
+                                    else:
+                                        continue
+                                elif evalmessage in resultdict:
+                                    result = False
+                                else:
+                                    continue
+                                msg = resultdict[evalmessage] if not result and evalmessage in resultdict else ""
+                                results.append({'eval': val["eval"], 'result': "passed" if result else "failed", 'message': msg})
+                    else:
+                        resultbool = resultval['result'][0]['expressions'][0]['value'] # [get_field_value(resultval, 'result[0].expressions[0].value')
                         result = parsebool(resultbool)
+                        results.append({'eval': rule_expr, 'result': "passed" if result else "failed", 'message': ''})
             else:
-                result = False
-        return result
+                results.append({'eval': rule_expr, 'result': "passed" if result else "failed", 'message': ''})
+        else:
+            results.append({'eval': rule_expr, 'result': "passed" if result else "failed", 'message': ''})
+        return results
 
 
 
@@ -269,13 +298,18 @@ class ComparatorV01:
                 json_data = json_from_file(fname)
                 if json_data and 'json' in json_data:
                     doc = json_data['json']
-                    self.snapshots.append({
+                    snapshot = {
                         'id': json_data['snapshotId'],
-                        'path': json_data['path'],
                         'structure': json_data['structure'],
                         'reference': json_data['reference'],
                         'source': json_data['source']
-                    })
+                    }
+                    if 'paths' in json_data:
+                        snapshot['paths'] = json_data['paths']
+                    else:
+                        snapshot['path'] = json_data['path']
+
+                    self.snapshots.append(snapshot)
         return doc
 
 
@@ -290,13 +324,17 @@ class ComparatorV01:
             logger.debug('Number of Snapshot Documents: %s', len(docs))
             if docs and len(docs):
                 doc = docs[0]['json']
-                self.snapshots.append({
+                snapshot = {
                     'id': docs[0]['snapshotId'],
-                    'path': docs[0]['path'],
                     'structure': docs[0]['structure'],
                     'reference': docs[0]['reference'],
                     'source': docs[0]['source']
-                })
+                }
+                if 'paths' in docs[0]:
+                    snapshot['paths'] = docs[0]['paths']
+                else:
+                    snapshot['path'] = docs[0]['path']
+                self.snapshots.append(snapshot)
         else:
             json_dir = '%s%s' % (get_test_json_dir(), self.container)
             if exists_dir(json_dir):
@@ -307,11 +345,15 @@ class ComparatorV01:
                         doc = json_data['json']
                         snapshot_val = {
                             'id': json_data['snapshotId'],
-                            'path': json_data['path'],
                             'structure': json_data['structure'],
                             'reference': json_data['reference'],
                             'source': json_data['source']
                         }
+                        if 'paths' in json_data:
+                            snapshot_val['paths'] = json_data['paths']
+                        else:
+                            snapshot_val['path'] = json_data['path']
+
                         singletest = get_from_currentdata(SINGLETEST)
                         if singletest:
                             snapshot_val['json'] = doc
@@ -323,6 +365,10 @@ class ComparatorV01:
         rego_file_name = None
         if 'dirpath' in self.testcase and self.testcase['dirpath']:
             rego_file_name = '%s/%s' % (self.testcase['dirpath'], rego_file)
+            if exists_file(rego_file_name):
+                pass
+            else:
+                rego_file_name = None
             return  rego_file_name
         isdb_fetch = get_dbtests()
         #It give same value for DB and SNAPSHOT, So for SNAPSHOT, we'll check it in 
@@ -360,7 +406,7 @@ class ComparatorV01:
 
 
     def validate(self):
-        result_val = {"result": "failed"}
+        result_val = [{"result": "failed"}]
         if self.format == TESTCASEV1:
             if self.snapshot_id:
                 docs = get_documents(self.collection, dbname=self.dbname,
@@ -373,29 +419,34 @@ class ComparatorV01:
                     if self.op in OPERATORS and OPERATORS[self.op]:
                         result = OPERATORS[self.op](self.data, self.loperand, self.roperand,
                                                     self.is_not, self.extras)
-                        result_val["result"] = "passed" if result else "failed"
-                        result_val["snapshots"] = [{
+                        result_val[0]["result"] = "passed" if result else "failed"
+                        result_val[0]["snapshots"] = [{
                             'id': docs[0]['snapshotId'],
-                            'path': docs[0]['path'],
                             'structure': docs[0]['structure'],
                             'reference': docs[0]['reference'],
                             'source': docs[0]['source']
                         }]
+                        if "paths" in docs[0]:
+                            result_val[0]["snapshots"][0]["paths"] = docs[0]["paths"]
+                        else:
+                            result_val[0]["snapshots"][0]["path"] = docs[0]["path"]
                 else:
-                    result_val.update({
+                    result_val[0].update({
                         "result": "skipped",
-                        "reason": "Missing documents for the snapshot"
+                        "message": "Missing documents for the snapshot"
                     })
             else:
-                result_val.update({
+                result_val[0].update({
                     "result": "skipped",
-                    "reason": "Missing snapshotId for testcase"
+                    "message": "Missing snapshotId for testcase"
                 })
         elif self.format == TESTCASEV2:
             if self.type == 'rego':
-                result = self.process_rego_test_case()
-                result_val["result"] = "passed" if result else "failed"
-                result_val['snapshots'] = self.snapshots
+                results = self.process_rego_test_case()
+                result_val = []
+                for result in results:
+                    result['snapshots'] = self.snapshots
+                    result_val.append(result)
             else:
                 logger.info('#' * 75)
                 logger.info('Actual Rule: %s', self.rule)
@@ -412,10 +463,10 @@ class ComparatorV01:
                 otherdata = {'dbname': self.dbname, 'snapshots': self.collection_data, 'container': self.container}
                 r_i = RuleInterpreter(children, **otherdata)
                 result = r_i.compare()
-                result_val["result"] = "passed" if result else "failed"
-                result_val['snapshots'] = r_i.get_snapshots()
+                result_val[0]["result"] = "passed" if result else "failed"
+                result_val[0]['snapshots'] = r_i.get_snapshots()
         else:
-            result_val.update({
+            result_val[0].update({
                 "result": "skipped",
                 "reason": "Unsupported testcase format"
             })
